Enum PowerPreference
pub enum PowerPreference {
None,
LowPower,
HighPerformance,
}Expand description
The power-usage preference for graphics adapters.
Variants
None
No power preference in which adapter should be chosen.
This is the default.
LowPower
The backend will prefer low power adapters over high performance ones.
HighPerformance
The backend will prefer adapters that are high performance.